@@ -1,7 +1,7 @@
 import os 
 import sqlite3 
 
-__version__ = version = '2.1.6.4'
+__version__ = version = '2.1.6.6'
 
 SPECIAL_CHARS = r"~!#$%^&*()-=+[]\{}:;,._||" + r'"' + r"'<>?/0123456789"
 INSERT_SPECIAL_CHARS = r"0123456789" + r"-_()[]:/.,@#&" 
@@ -25,11 +25,19 @@ def __selroutine():
  
 def __sroutine1():
     
-    import subprocess , sys   
+       
+    global ProgPath, DB, DBCursor, DBFile  
     os.environ.update({'METEOR_DICEWARE_INTERNAL_WORDLIST_CREATION_PROCESS_UNDERWAY' :  '1' })   
-    subprocess.call([sys.executable, '-m' , 'meteor_diceware.utils' , 'create' , 'main' , '-w' ] , env = os.environ)
-    subprocess.call([sys.executable , '-m' , 'meteor_diceware.utils' , 'edit' , 'main' , '-f' , os.path.join(ProgPath , 'actual_diceware.txt')] , env = os.environ )
-
+    DB.close()
+    
+    import runpy 
+    runpy.run_path(os.path.join(ProgPath , 'failsafe.py') , init_globals  = {'dwaretxt' : os.path.join(ProgPath , 'actual_diceware.txt')})
+    
+    DB = sqlite3.connect(DBFile)
+    DBCursor = DB.cursor()
+    
+    return None     
+    
 __initdb = lambda : DBCursor.executescript(open(os.path.join(ProgPath , 'init.sql') , 'r' , encoding = 'utf8').read())
 
 if 'METEOR_DICEWARE_INTERNAL_WORDLIST_CREATION_PROCESS_UNDERWAY' in os.environ:
